export function Clustering(fD , id){ // function to handle Clustering.
  
  	var w = 800, h = 500;
    
    var radius = 24;
    var color = d3.scaleOrdinal(d3.schemePaired);
    var centerScale = d3.scalePoint().padding(1).range([0, w]);
    var forceStrength = 0.05;
    	
  	d3.select(id).append("canvas").attr("width", w)
      .attr("height", 50)
  
  	var divv = d3.select(id).append("div")    
                    .attr("id", "toolbar")
    								.attr('transform', 'translate(' + 20 + ',' + 150 + ')');
  
  	var data = fD;
  	var titles = Object.keys(data[0]);
  	console.log(titles); 
  
  	divv.append("input")
  	.attr( 'type', 'button')
    .attr( 'id', 'all')
  	.attr( 'class', 'buttoni active')
		.attr( 'value', 'All');
  
  	for(var i=1;i<titles.length;i++)
    {
      divv.append("input")
      .attr( 'type', 'button')
      .attr( 'id', titles[i])
      .attr( 'class', 'buttoni')
      .attr( 'value', 'By '+titles[i]);
    }
  
  
    var svg = d3.select(id).append("svg")
      .attr("width", w)
      .attr("height", h)

    var simulation = d3.forceSimulation()
            .force("collide",d3.forceCollide( function(d){
              	return d.r + 7 }).iterations(16) 
            )
            .force("charge", d3.forceManyBody())
            .force("y", d3.forceY().y(h / 2))
            .force("x", d3.forceX().x(w / 2))
    
    
      
      data.forEach(function(d){
        d.r = radius;
        d.x = w / 2;
        d.y = h / 2;
      })
      
      
      
      
      var circles = svg.selectAll("circle")
      	.data(data, function(d){ return d.ID ;});
      
      var gg = circles.enter().append("g");
      
      var circlesEnter = gg.append("circle")
      	.attr("r", function(d, i){ return d.r; })
        .attr("cx", function(d, i){ return 175 + 25 * i + 2 * i ** 2; })
				.attr("cy", function(d, i){ return 250; })
      	.style("fill", function(d, i){ return color(d.ID); })
      	.style("stroke", function(d, i){ return color(d.ID); })
      	.style("stroke-width", 10)
      	.style("pointer-events", "all")
      	.call(d3.drag()
                .on("start", dragstarted)
                .on("drag", dragged)
                .on("end", dragended));
      
    	var texti = gg.append("text")
        .attr("x", function(d, i){ return 175 + 25 * i + 2 * i ** 2;})
      	.attr("y", function(d, i){ return 250;})
        .text(function(d){return d.ID})
      	.attr('text-anchor', 'middle')
        .attr('alignment-baseline', 'middle')
      	.style('font-size', 14 + 'px');
      
      circles = circles.merge(circlesEnter)
      
      function ticked() {

        circles
            .attr("cx", function(d){ return d.x; })
            .attr("cy", function(d){ return d.y; });
        texti
        		.attr("x", function(d){ return d.x; })
            .attr("y", function(d){ return d.y; });
      }   

      simulation
            .nodes(data)
            .on("tick", ticked);
      
      function dragstarted(d,i) {
        if (!d3.event.active) simulation.alpha(1).restart();
        d.fx = d.x;
        d.fy = d.y;
      }

      function dragged(d,i) {
        //console.log("dragged " + i)
        d.fx = d3.event.x;
        d.fy = d3.event.y;
      }

      function dragended(d,i) {
        //console.log("dragended " + i)
        if (!d3.event.active) simulation.alphaTarget(0);
        d.fx = null;
        d.fy = null;
        var me = d3.select(this)
        //console.log(me.classed("selected"))
        me.classed("selected", !me.classed("selected"))
        
        d3.selectAll("circle")
          .style("fill", function(d, i){ return color(d.ID); })
      	
        d3.selectAll("circle.selected")
          .style("fill", "none")
      	
      } 
      
      function groupBubbles() {
        hideTitles();

        // @v4 Reset the 'x' force to draw the bubbles to the center.
        simulation.force('x', d3.forceX().strength(forceStrength).x(w / 2));

        // @v4 We can reset the alpha value and restart the simulation
        simulation.alpha(1).restart();
      }
      
      function splitBubbles(byVar) {
        
        centerScale.domain(data.map(function(d){ return d[byVar]; }));
        
        if(byVar == "all"){
          hideTitles()
        } else {
	        showTitles(byVar, centerScale);
        }
        
        // @v4 Reset the 'x' force to draw the bubbles to their year centers
        simulation.force('x', d3.forceX().strength(forceStrength).x(function(d){ 
        	return centerScale(d[byVar]);
        }));

        // @v4 We can reset the alpha value and restart the simulation
        simulation.alpha(2).restart();
      }
      
      function hideTitles() {
        svg.selectAll('.title').remove();
      }

      function showTitles(byVar, scale) {
        // Another way to do this would be to create
        // the year texts once and then just hide them.
       	var titles = svg.selectAll('.title')
          .data(scale.domain());
        
        titles.enter().append('text')
          	.attr('class', 'title')
        	.merge(titles)
            .attr('x', function (d) { return scale(d); })
            .attr('y', 100)
            .attr('text-anchor', 'middle')
            .text(function (d) { return byVar + ' ' + d; })
        		.style('font-size', 20 + 'px');
        
        titles.exit().remove() 
      }
      
      function setupButtons() {
        d3.selectAll('.buttoni')
          .on('click', function () {
          	
            // Remove active class from all buttons
            d3.selectAll('.buttoni').classed('active', false);
            // Find the button just clicked
            var button = d3.select(this);

            // Set it as the active button
            button.classed('active', true);

            // Get the id of the button
            var buttonId = button.attr('id');

	          //console.log(buttonId)
            // Toggle the bubble chart based on
            // the currently clicked button.
            splitBubbles(buttonId);
          });
      }
      
      setupButtons()
      

  
}
 
