import { histoGram } from './histogram.js';
import { Bar } from './bar.js';
import { pieChart,legend } from './piechart.js';
import { Continuum } from './continuum.js';
import { Table } from './table.js';
import { tukeyBox } from './tukeybox.js';
import { Cartesian } from './cartesian.js';
import { lineChart } from './linechart.js';
import { areaChart } from './areachart.js';
import { scatterPlot } from './scatterplot.js';
import { Spectrogram_ } from './spectrogram.js';
import { radarChart } from './radarchart.js';
import { Sankey } from './sankey.js';
import { Map } from './map.js';
import { parallelCoor } from './parallelcoordinates.js';
import { Lens } from './lens.js';
import { treeMap } from './treemap.js';
import { hyperbolicTree } from './hyperbolictree.js';
import { entityRelation } from './entityrelation.js';
import { Tree } from './tree.js';
import { Cycle } from './cycle.js';
import { petriNet } from './petrinet.js';
import { timeLine } from './timeline.js';
import { flowChart } from './flowchart.js';
import { flowChartHead } from './flowchartHead.js';
import { dataFlow } from './dataflow.js';
import { dataFlowHead } from './dataflowHead.js';
import { systemDynamics } from './systemdynamics.js';
import { systemDynamicsHead } from './systemdynamicsHead.js';
import { Venn } from './venn.js';
import { Clustering } from './clustering.js';
import { semanticNetwork } from './semanticnet.js';
import { Mindmap } from './mindmap.js';
import { layerChart } from './layerchart.js';
import { synergyMap } from './synergymap.js';
import { concentricCircles } from './concentriccircles.js';
import { forceField } from './forcefield.js';


export function dashboard(id, fData, typei){
  
  switch(typei) {
      case 'Bar':
      	var titles = Object.keys(fData[0]);
        var sF = fData.map(function(d){return [d[titles[0]],d[titles[1]]];});
    		Bar(sF, id, titles)
        break;
      case 'Histogram':
      	var titles = Object.keys(fData[0]);
        var sF = fData.map(function(d){return [d[titles[0]],d[titles[1]]];});
    		histoGram(sF, id, titles)
        break;
      case 'Pie':
      	var titles = Object.keys(fData[0]);
        pieChart(fData, id, titles); 
        legend(fData, id, titles); 
        break;
      case 'Continuum':
        Continuum(fData, id); 
        break;
      case 'Table':
        Table(fData, id);
        break;
      case "Tukey Box":
      	var titles = Object.keys(fData[0]);
      	var key = fData[0][titles[0]];//title
      	for(let i=0;i<fData.length;i++)
          	delete fData[i][titles[0]];      
        tukeyBox(fData, id, key);
        break;
      case 'Cartesian':
        Cartesian(fData, id);
        break;
      case 'lineChart':
        lineChart(fData, id);
        break;
      case 'areaChart':
        areaChart(fData, id);
        break;
      case 'scatterPlot':
        scatterPlot(fData, id);
        break;
      case 'Spectrogram':
        Spectrogram_(fData, id);
        break;
      case 'radarChart':
      	//console.log(fData);
      	var len = fData.length;
      	var titles = Object.keys(fData[0]);
      	fData.forEach(function(d){ d[titles[2]] = +d[titles[2]]; });
      	var values=[];
      	
				for(let i=0 ; i<len ; i++)
          	values[i] = fData[i][titles[0]];

      	var titles2  = Array.from(new Set(values));
        
      	var len2 = Array.from(new Set(values)).length;//3
      	var len3 = len/len2;//6
      	
      	for(let i=0;i<fData.length;i++)
          	delete fData[i][titles[0]];
      
      	var newValues = [];//3 ta araye 6 objecte
        for (var i = 0; i < len2; i++) {
             newValues[i] = [];
        }
      	var k=0;
      	for(let i=0;i<len2;i++)
        {
          	for(let j=0;j<len3;j++)
        		{
          			newValues[i][j]=fData[k];
              	k++;
            }
        }
        radarChart(newValues, id, titles2);
        break;
      case 'Sankey':
        Sankey(fData, id);
      	break;
      case 'Map':
        Map(fData, id);
      	break;
      case 'parallelCoor':
      	console.log(fData);
        parallelCoor(fData, id);
      	break;
      case 'Lens':
        Lens(fData, id);
      	break;
      case 'treeMap':
        treeMap(fData, id);
      	break;
      case 'hyperbolicTree':
        hyperbolicTree(fData, id);
      	break;
      case 'entityRelation':
        entityRelation(fData, id);
      	break;
      case 'Tree':
        Tree(fData, id);
      	break;
      case 'Cycle':
        Cycle(fData, id);
      	break;
      case 'petriNet':
        petriNet(fData, id);
      	break;
    	case 'timeLine':
        timeLine(fData, id);
      	break;
      case 'flowChart':
        flowChart(fData, id);
      	flowChartHead();
      	break;
      case 'dataFlow':
        dataFlow(fData, id);
      	dataFlowHead();
      	break;
      case 'systemDynamics':
        systemDynamics(fData, id, 0);
      	systemDynamicsHead();
      	break;
      case 'Venn':
        Venn(fData, id);
      	break;
      case 'Clustering':
        Clustering(fData, id);
      	break;
      case 'semanticNetwork':
        semanticNetwork(fData, id);
      	break;
      case 'Mindmap':
        Mindmap(fData, id);
      	break;
      case 'layerChart':
        layerChart(fData, id);
      	break;
      case 'softSystem':
        systemDynamics(fData, id, 1);
      	systemDynamicsHead();
      	break;
      case 'squareOfOppositions':
        systemDynamics(fData, id, 2);
      	systemDynamicsHead();
      	break;
      case 'mintoPyramid':
        systemDynamics(fData, id, 3);
      	systemDynamicsHead();
      	break;
    	case 'synergyMap':
      	synergyMap(fData, id);
      	break;
      case 'concentricCircles':
      	concentricCircles(fData, id);
      	break;
      case 'causeEffectChains':
        systemDynamics(fData, id, 4);
      	systemDynamicsHead();
      	break;
      case 'forceField':
        forceField(fData, id);
      	break;
      default:
        break;
    }
}