export function scatterPlot(fD , id){ // function to handle scatterPlot.
  
  var margin = {top: 50, right: 200, bottom: 60, left: 70},
    width = 770 - margin.left - margin.right,
    height = 560 - margin.top - margin.bottom;
  
  var data = fD;
  var titles = Object.keys(data[0]);	
  
  
  var xValue = function(d) { return d[titles[1]];}, // data -> value
    xScale = d3.scaleLinear().range([0, width]), // value -> display
    xMap = function(d) { return xScale(xValue(d));}, // data -> display
    xAxis = d3.axisBottom(xScale);

  // setup y
  var yValue = function(d) { return d[titles[2]];}, // data -> value
      yScale = d3.scaleLinear().range([height, 0]), // value -> display
      yMap = function(d) { return yScale(yValue(d));}, // data -> display
      yAxis = d3.axisLeft(yScale);

  // setup fill color
  var cValue = function(d) { return d[titles[0]];},
      color = d3.scaleOrdinal(d3.schemeCategory10);

  // add the graph canvas to the body of the webpage
  var svg = d3.select(id).append("svg")
      .attr("width", width + margin.left + margin.right)
      .attr("height", height + margin.top + margin.bottom)
    .append("g")
      .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

  // add the tooltip area to the webpage
  var tooltip = d3.select(id).append("div")
      .attr("class", "tooltip")
      .style("opacity", 0);



    // change string (from CSV) into number format
    data.forEach(function(d) {
      d[titles[1]] = +d[titles[1]]
      d[titles[2]] = +d[titles[2]];
  //    console.log(d);
  });

  // don't want dots overlapping axis, so add in buffer to data domain
  xScale.domain([d3.min(data, xValue)-1, d3.max(data, xValue)+1]);
  yScale.domain([d3.min(data, yValue)-1, d3.max(data, yValue)+1]);

  // x-axis
  svg.append("g")
      .attr("class", "x axis")
      .attr("transform", "translate(0," + height + ")")
      .call(xAxis)
    .append("text")
      .attr("class", "label")
      .attr("x", width)
      .attr("y", -6)
      .style("text-anchor", "end")
      .text("Calories");

  // text label for the x axis
  svg.append("text")             
            .attr("transform", "translate(" + (width/2) + " ," + (height + 50) + ")")
            .style("text-anchor", "middle")
            .text(titles[1]);
  
  // y-axis
  svg.append("g")
      .attr("class", "y axis")
      .call(yAxis)
    .append("text")
      .attr("class", "label")
      .attr("transform", "rotate(-90)")
      .attr("y", 6)
      .attr("dy", ".71em")
      .style("text-anchor", "end")
      .text("Protein (g)");
  // text label for the y axis
  svg.append("text")             
            .attr("transform", "translate(" + (-40) + " ," + (height/2) + ")rotate(-90)")
            .style("text-anchor", "middle")
            .text(titles[2]);

  // draw dots
  svg.selectAll(".dot")
      .data(data)
    .enter().append("circle")
      .attr("class", "dot")
      .attr("r", 5)
      .attr("cx", xMap)
      .attr("cy", yMap)
      .style("fill", function(d) { return color(cValue(d));}) 
      .on("mouseover", function(d) {
          tooltip.transition()
               .duration(200)
               .style("opacity", .9);
          tooltip.html(d["Cereal Name"] + "<br/> (" + xValue(d) 
	        + ", " + yValue(d) + ")")
               .style("left", (d3.event.pageX + 5) + "px")
               .style("top", (d3.event.pageY - 28) + "px");
      })
      .on("mouseout", function(d) {
          tooltip.transition()
               .duration(500)
               .style("opacity", 0);
      });

  // draw legend
  var legend = svg.selectAll(".legend")
      .data(color.domain())
    .enter().append("g")
      .attr("class", "legend")
      .attr("transform", function(d, i) { return "translate(150," + i * 20 + ")"; });

  // draw legend colored rectangles
  legend.append("rect")
      .attr("x", width - 18)
      .attr("width", 18)
      .attr("height", 18)
      .style("fill", color);

  // draw legend text
  legend.append("text")
      .attr("x", width - 24)
      .attr("y", 9)
      .attr("dy", ".35em")
      .style("text-anchor", "end")
      .text(function(d) { return d;})

};
 